@@ -1,7 +1,7 @@
 package Bencher::Scenario::IODParsingModules;
 
-our $DATE = '2016-06-26'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2017-01-25'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -11,6 +11,11 @@ use File::ShareDir::Tarball qw(dist_dir);
 
 our $scenario = {
     summary => 'Benchmark IOD/INI parsing modules',
+    modules => {
+        # minimum versions
+        'Config::IOD' => {version=>'0.31'},
+        'Config::IOD::Reader' => {version=>'0.31'},
+    },
     participants => [
         {
             module => 'Config::IOD::Reader',
@@ -68,7 +73,7 @@ Bencher::Scenario::IODParsingModules - Benchmark IOD/INI parsing modules
 
 =head1 VERSION
 
-This document describes version 0.04 of Bencher::Scenario::IODParsingModules (from Perl distribution Bencher-Scenario-IODParsingModules), released on 2016-06-26.
+This document describes version 0.05 of Bencher::Scenario::IODParsingModules (from Perl distribution Bencher-Scenario-IODParsingModules), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -82,17 +87,21 @@ To run module startup overhead benchmark:
 
 For more options (dump scenario, list/include/exclude/add participants, list/include/exclude/add datasets, etc), see L<bencher> or run C<bencher --help>.
 
+=head1 DESCRIPTION
+
+Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+
 =head1 BENCHMARKED MODULES
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
-L<Config::IOD::Reader> 0.24
-
-L<Config::IOD> 0.29
-
 L<Config::INI::Reader> 0.025
 
-L<Config::IniFiles> 2.92
+L<Config::IOD> 0.33
+
+L<Config::IOD::Reader> 0.32
+
+L<Config::IniFiles> 2.93
 
 L<Config::Simple::Conf> 2.002
 
@@ -156,44 +165,45 @@ Code template:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.2 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.
 
 Benchmark with default options (C<< bencher -m IODParsingModules >>):
 
+ #table1#
  +----------------------+------------------------------+-----------+-----------+------------+---------+---------+
  | participant          | dataset                      | rate (/s) | time (ms) | vs_slowest |  errors | samples |
  +----------------------+------------------------------+-----------+-----------+------------+---------+---------+
- | Config::IniFiles     | extra-bench-basic-compat.iod |       300 |     3.4   |       1    | 1.5e-05 |      20 |
- | Config::INI::Reader  | extra-bench-basic-compat.iod |      1200 |     0.836 |       4.04 | 4.8e-07 |      20 |
- | Config::IniFiles     | extra-bench-typical1.iod     |      1430 |     0.7   |       4.83 | 6.9e-07 |      20 |
- | Config::IOD          | extra-bench-basic-compat.iod |      1510 |     0.663 |       5.1  | 4.8e-07 |      20 |
- | Config::IOD          | extra-bench-basic.iod        |      1500 |     0.65  |       5.2  | 1.3e-06 |      20 |
- | Config::IOD::Reader  | extra-bench-basic-compat.iod |      1900 |     0.526 |       6.43 | 2.7e-07 |      20 |
- | Config::IOD::Reader  | extra-bench-basic.iod        |      1930 |     0.518 |       6.52 | 2.7e-07 |      20 |
- | Config::Simple::Conf | extra-bench-basic-compat.iod |      2140 |     0.466 |       7.25 | 4.5e-07 |      23 |
- | Config::INI::Reader  | extra-bench-typical1.iod     |      6200 |     0.16  |      21    | 2.1e-07 |      21 |
- | Config::IOD          | extra-bench-typical1.iod     |      6800 |     0.15  |      23    | 1.9e-07 |      26 |
- | Config::Simple::Conf | extra-bench-typical1.iod     |      8900 |     0.11  |      30    | 2.2e-07 |      29 |
- | Config::IOD::Reader  | extra-bench-typical1.iod     |     10000 |     0.098 |      35    | 1.1e-07 |      32 |
+ | Config::IniFiles     | extra-bench-basic-compat.iod |       230 |     4.3   |       1    | 4.9e-06 |      20 |
+ | Config::INI::Reader  | extra-bench-basic-compat.iod |       840 |     1.2   |       3.6  | 2.2e-06 |      21 |
+ | Config::IOD          | extra-bench-basic-compat.iod |      1100 |     0.92  |       4.7  | 1.5e-06 |      20 |
+ | Config::IOD          | extra-bench-basic.iod        |      1130 |     0.887 |       4.87 | 4.6e-07 |      22 |
+ | Config::IniFiles     | extra-bench-typical1.iod     |      1100 |     0.88  |       4.9  | 1.1e-06 |      20 |
+ | Config::IOD::Reader  | extra-bench-basic-compat.iod |      1400 |     0.7   |       6.2  | 9.1e-07 |      20 |
+ | Config::IOD::Reader  | extra-bench-basic.iod        |      1400 |     0.7   |       6.2  | 9.1e-07 |      20 |
+ | Config::Simple::Conf | extra-bench-basic-compat.iod |      1600 |     0.64  |       6.8  | 1.1e-06 |      21 |
+ | Config::INI::Reader  | extra-bench-typical1.iod     |      4200 |     0.24  |      18    | 6.4e-07 |      20 |
+ | Config::IOD          | extra-bench-typical1.iod     |      4700 |     0.21  |      20    | 4.3e-07 |      20 |
+ | Config::Simple::Conf | extra-bench-typical1.iod     |      6100 |     0.16  |      26    | 4.1e-07 |      28 |
+ | Config::IOD::Reader  | extra-bench-typical1.iod     |      7600 |     0.13  |      33    | 2.7e-07 |      20 |
  +----------------------+------------------------------+-----------+-----------+------------+---------+---------+
 
 
 Benchmark module startup overhead (C<< bencher -m IODParsingModules --module-startup >>):
 
- +----------------------+-----------+------------------------+------------+---------+---------+
- | participant          | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
- +----------------------+-----------+------------------------+------------+---------+---------+
- | Config::INI::Reader  |      26   |                   23.4 |        1   | 5.6e-05 |      21 |
- | Config::IniFiles     |      26   |                   23.4 |        1   | 8.3e-05 |      21 |
- | Config::IOD::Reader  |       8.3 |                    5.7 |        3.2 | 2.4e-05 |      21 |
- | Config::IOD          |       8.2 |                    5.6 |        3.2 | 5.5e-05 |      20 |
- | Config::Simple::Conf |       4.2 |                    1.6 |        6.3 | 4.1e-05 |      22 |
- | perl -e1 (baseline)  |       2.6 |                    0   |       10   | 1.2e-05 |      21 |
- +----------------------+-----------+------------------------+------------+---------+---------+
+ #table2#
+ +----------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+ | participant          | proc_private_dirty_size (MB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
+ +----------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+ | Config::INI::Reader  | 4.7                          | 8.1                | 28             |      38   |                   31.9 |        1   | 6.5e-05 |      20 |
+ | Config::IniFiles     | 1                            | 4.3                | 16             |      38   |                   31.9 |        1   |   9e-05 |      20 |
+ | Config::IOD::Reader  | 1.4                          | 4.8                | 19             |      14   |                    7.9 |        2.7 | 7.9e-05 |      20 |
+ | Config::IOD          | 5.4                          | 9.1                | 33             |      14   |                    7.9 |        2.8 | 5.3e-05 |      21 |
+ | Config::Simple::Conf | 0.82                         | 4                  | 16             |       8.4 |                    2.3 |        4.5 | 5.7e-05 |      21 |
+ | perl -e1 (baseline)  | 1.5                          | 4.8                | 19             |       6.1 |                    0   |        6.2 | 3.8e-05 |      21 |
+ +----------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
 
-=head1 DESCRIPTION
 
-Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
 
 =head1 HOMEPAGE
 
@@ -217,7 +227,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
